@@ -7,7 +7,7 @@ use warnings;
 use autodie;
 use namespace::autoclean;
 
-our $VERSION = '0.77';
+our $VERSION = '0.78';
 
 use Dist::Zilla 6.0;
 
@@ -394,7 +394,23 @@ sub _build_files_to_copy_from_build {
     push @files,
         $self->make_tool eq 'MakeMaker' ? 'Makefile.PL' : 'Build.PL';
 
-    push @files, 'ppport.h' if $self->_has_xs;
+    my $rule = Path::Iterator::Rule->new;
+    my $dist = $self->dist;
+
+    # We need to skip any existing build dirs
+    my $iter = $rule->file->name('ppport.h')->skip(
+        $rule->new->dir->name(qr{^\Q$dist\E-\d+\.\d+}),
+        $rule->new->dir->name('.build')
+    )->iter('.');
+
+    if ( my $ppport = $iter->() ) {
+
+        # If the file is in a subdir we end up with a name like
+        # "./foo/ppport.h" - the initial "./" bit will confuse the gatherdir
+        # exclude rules.
+        $ppport =~ s{^\./}{};
+        push @files, $ppport;
+    }
 
     return \@files;
 }
@@ -784,7 +800,7 @@ Dist::Zilla::PluginBundle::DROLSKY - DROLSKY's plugin bundle
 
 =head1 VERSION
 
-version 0.77
+version 0.78
 
 =head1 SYNOPSIS
 
